==> concordance_1.0.orig.tar.bz2: concordance-1.0/libconcord/lc_internal.h <==
/*
 * vi: formatoptions+=tc textwidth=80 tabstop=8 shiftwidth=8 noexpandtab:
 *
 * $Id: lc_internal.h,v 1.3 2013/04/10 04:17:05 jaymzh Exp $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Copyright 2007 Kevin Timmerman
 * Copyright 2008 Phil Dibowitz
 */

#ifndef LC_INTERNAL_H
#define LC_INTERNAL_H

#ifdef WIN32 /* BEGIN WINDOWS SECTION */

#include <windows.h>
/*
 * FIXME: We need to fix the code that is generating these warnings!!
 */
#if _MSC_VER >= 1400
#pragma warning( disable : 4996 )
#endif

#else /* END WINDOWS SECTION, BEGIN NON-WINDOWS SECTION */

#define LIBUSB

#define stricmp strcasecmp
#define strnicmp strncasecmp

#endif /* END NON-WINDOWS SECTION */

/* BEGIN GLOBAL SECTION */

#ifdef _DEBUG
#define debug(FMT,...) fprintf(stderr, "DEBUG (%s): "FMT"\n", __FUNCTION__,\
         ##__VA_ARGS__);
#else
#define debug(FMT,...)
#endif

#include <string>
#include <stdint.h>
using namespace std;

void report_net_error(const char *msg);
/* NOTE: 1 for yes, 0 for no, unlike some other functions. */
int is_z_remote();
int is_usbnet_remote();
int is_mh_remote();

#endif // ifndef LC_INTERNAL_H

==> concordance_1.2.orig.tar.bz2: concordance-1.2/libconcord/lc_internal.h <==
/*
 * vim:tw=80:ai:tabstop=4:softtabstop=4:shiftwidth=4:expandtab
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Copyright 2007 Kevin Timmerman
 * Copyright 2008 Phil Dibowitz
 */

#ifndef LC_INTERNAL_H
#define LC_INTERNAL_H

#ifdef _WIN32 /* BEGIN WINDOWS SECTION */

#include <windows.h>

#else /* END WINDOWS SECTION, BEGIN NON-WINDOWS SECTION */

#define stricmp strcasecmp
#define strnicmp strncasecmp

#endif /* END NON-WINDOWS SECTION */

/* BEGIN GLOBAL SECTION */

#ifdef _DEBUG
#define debug(FMT,...) fprintf(stderr, "DEBUG (%s): "FMT"\n", __FUNCTION__,\
         ##__VA_ARGS__);
#else
#define debug(FMT,...)
#endif

#include <string>
#include <stdint.h>
using namespace std;

void report_net_error(const char *msg);
/* NOTE: 1 for yes, 0 for no, unlike some other functions. */
int is_z_remote();
int is_usbnet_remote();
int is_mh_remote();

#endif // ifndef LC_INTERNAL_H
